@@ -1,7 +1,7 @@
-import json
 import unittest
 
 import requests
+import ujson
 
 from wikibaseintegrator import wbi_login
 from wikibaseintegrator.wbi_backoff import wbi_backoff
@@ -11,7 +11,7 @@ from wikibaseintegrator.wbi_config import config
 class TestMethods(unittest.TestCase):
     def test_all(self):
         config['BACKOFF_MAX_TRIES'] = 2
-        config['BACKOFF_MAX_VALUE'] = 2
+        config['BACKOFF_MAX_VALUE'] = 3
         with self.assertRaises(requests.RequestException):
             bad_http_code()
         with self.assertRaises(requests.RequestException):
@@ -21,10 +21,12 @@ class TestMethods(unittest.TestCase):
 
         assert good_http_code() == 200
 
-        with self.assertRaises(json.JSONDecodeError):
+        with self.assertRaises(ValueError):
             bad_json()
 
 
+# @backoff.on_exception(backoff.expo, (requests.exceptions.Timeout, requests.exceptions.ConnectionError, requests.HTTPError, JSONDecodeError), max_time=60)
+
 @wbi_backoff()
 def bad_http_code():
     r = requests.get("https://httpbin.org/status/400")
@@ -41,7 +43,7 @@ def good_http_code():
 
 @wbi_backoff()
 def bad_json():
-    json.loads("<xml>I failed :(</xml>")
+    ujson.loads("<xml>I failed :(</xml>")
 
 
 @wbi_backoff()
@@ -50,4 +52,4 @@ def bad_request():
 
 
 def bad_login():
-    wbi_login.Login("name", "pass", mediawiki_api_url="www.wikidataaaaaaaaa.org")
+    wbi_login.Clientlogin(user='name', password='pass', mediawiki_api_url="www.wikidataaaaaaaaa.org")
