@@ -1,5 +1,5 @@
 import re
-from typing import Any, Union
+from typing import Any, Optional, Union
 
 from wikibaseintegrator.datatypes.basedatatype import BaseDataType
 
@@ -16,7 +16,7 @@ class Property(BaseDataType):
         }}
     '''
 
-    def __init__(self, value: Union[str, int] = None, **kwargs: Any):
+    def __init__(self, value: Optional[Union[str, int]] = None, **kwargs: Any):
         """
         Constructor, calls the superclass BaseDataType
 
@@ -27,7 +27,7 @@ class Property(BaseDataType):
         super().__init__(**kwargs)
         self.set_value(value=value)
 
-    def set_value(self, value: Union[str, int] = None):
+    def set_value(self, value: Optional[Union[str, int]] = None):
         assert isinstance(value, (str, int)) or value is None, f"Expected str or int, found {type(value)} ({value})"
 
         if value:
