@@ -1,17 +1,18 @@
 from __future__ import annotations
 
 import copy
+from abc import abstractmethod
 from typing import Any, Callable, Dict, List, Optional, Union
 
 from wikibaseintegrator.models.basemodel import BaseModel
 from wikibaseintegrator.models.qualifiers import Qualifiers
 from wikibaseintegrator.models.references import Reference, References
 from wikibaseintegrator.models.snaks import Snak, Snaks
-from wikibaseintegrator.wbi_enums import ActionIfExists, WikibaseRank
+from wikibaseintegrator.wbi_enums import ActionIfExists, WikibaseRank, WikibaseSnakType
 
 
 class Claims(BaseModel):
-    def __init__(self):
+    def __init__(self) -> None:
         self.claims: Dict[str, List[Claim]] = {}
 
     @property
@@ -25,7 +26,7 @@ class Claims(BaseModel):
     def get(self, property: str) -> List[Claim]:
         return self.claims[property]
 
-    def remove(self, property: str = None) -> None:
+    def remove(self, property: Optional[str] = None) -> None:
         if property in self.claims:
             for prop in self.claims[property]:
                 if prop.id:
@@ -39,7 +40,7 @@ class Claims(BaseModel):
         """
 
         :param claims: A Claim, list of Claim or just a Claims object to add to this Claims object.
-        :param action_if_exists: Replace or append the statement. You can force an addition if the declaration already exists.
+        :param action_if_exists: Replace or append the statement. You can force an addition if the declaration already exists. Defaults to REPLACE_ALL.
             KEEP: The original claim will be kept and the new one will not be added (because there is already one with this property number)
             APPEND_OR_REPLACE: The new claim will be added only if the new one is different (by comparing values)
             FORCE_APPEND: The new claim will be added even if already exists
@@ -130,14 +131,15 @@ class Claims(BaseModel):
 class Claim(BaseModel):
     DTYPE = 'claim'
 
-    def __init__(self, qualifiers: Qualifiers = None, rank: WikibaseRank = None, references: Union[References, List[Union[Claim, List[Claim]]]] = None) -> None:
+    def __init__(self, qualifiers: Optional[Qualifiers] = None, rank: Optional[WikibaseRank] = None, references: Optional[Union[References, List[Union[Claim, List[Claim]]]]] = None, snaktype: WikibaseSnakType = WikibaseSnakType.KNOWN_VALUE) -> None:
         """
 
         :param qualifiers:
         :param rank:
         :param references: A References object, a list of Claim object or a list of list of Claim object
+        :param snaktype:
         """
-        self.mainsnak = Snak(datatype=self.DTYPE)
+        self.mainsnak = Snak(datatype=self.DTYPE, snaktype=snaktype)
         self.type = 'statement'
         self.qualifiers = qualifiers or Qualifiers()
         self.qualifiers_order = []
@@ -215,7 +217,7 @@ class Claim(BaseModel):
 
     @rank.setter
     def rank(self, value: WikibaseRank):
-        """Parse the rank. The enum thows an error if it is not one of the recognized values"""
+        """Parse the rank. The enum throws an error if it is not one of the recognized values"""
         self.__rank = WikibaseRank(value)
 
     @property
@@ -326,7 +328,7 @@ class Claim(BaseModel):
 
         raise super().__eq__(other)
 
-    def equals(self, that: Claim, include_ref: bool = False, fref: Callable = None) -> bool:
+    def equals(self, that: Claim, include_ref: bool = False, fref: Optional[Callable] = None) -> bool:
         """
         Tests for equality of two statements.
         If comparing references, the order of the arguments matters!!!
@@ -362,5 +364,6 @@ class Claim(BaseModel):
 
         return len(oldrefs) == len(newrefs) and all(any(ref_equal(oldref, newref) for oldref in oldrefs) for newref in newrefs)
 
+    @abstractmethod
     def get_sparql_value(self) -> str:
         pass
